scanpydoc |pypi| |docs| |tests| |checks| |cov|
==============================================

A collection of Sphinx extensions similar to (but more flexible than) numpydoc.

Check the self-documenting documentation at https://icb-scanpydoc.readthedocs-hosted.com

.. |pypi| image:: https://img.shields.io/pypi/v/scanpydoc.svg
   :target: https://pypi.org/project/scanpydoc/
   :alt: PiPI version
.. |docs| image:: https://readthedocs.com/projects/icb-scanpydoc/badge/
   :target: https://icb-scanpydoc.readthedocs-hosted.com/
   :alt: doc build status
.. |tests| image:: https://github.com/theislab/scanpydoc/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/theislab/scanpydoc/actions/workflows/ci.yml
   :alt: python test status
.. |checks| image:: https://results.pre-commit.ci/badge/github/theislab/scanpydoc/main.svg
   :target: https://results.pre-commit.ci/latest/github/theislab/scanpydoc/main
   :alt: pre-commit.ci status
.. |cov| image:: https://codecov.io/gh/theislab/scanpydoc/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/theislab/scanpydoc
   :alt: coverage
